@@ -6,15 +6,17 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <X11/Xlib.h>
+#include <errno.h>
+#include <pthread.h>
+
+
 #include "callbacks.h"
 #include "interface.h"
 #include "support.h"
 #include "vncviewer.h"
-#include <errno.h>
 
 void makeTable_dialog_viewset(int pCnt);
 void makeList_dialog_viewset(int pCnt);
-GtkWidget *create_expandedwindow(void);
 void expanding_screen(void);
 GtkWidget *create_rightclickmenu1 (gpointer user_data);
 GtkWidget *create_rightclickmenu2 (gpointer user_data);
@@ -24,7 +26,6 @@ void makeCombobox1_dialog_send(void);
 void makeCombobox2_dialog_send(void);
 void send_start(void);
 void locking_start(void);
-GtkWidget *create_dialog_sendstop (int c_num);
 
 gint keyindex;
 extern Display *dpy;
@@ -47,8 +48,7 @@ extern IMAGEINFO *iinfo_ex;
 
 GtkWidget *window_ex;
 extern int exwindowWidth, exwindowHeight;
-GtkWidget *label_ex;
-GtkWidget *window_ex_togglebutton;
+GtkWidget *drawingarea_ex;
 
 GtkWidget *dialog_send;
 int maxcastnum = 0;
@@ -63,23 +63,30 @@ GtkWidget *dialog_send_table2;
 GtkWidget *dialog_send_label_ID;
 GtkWidget *dialog_send_comboboxentry1;
 GtkWidget *dialog_send_comboboxentry2;
-extern GtkWidget *dialog_send_viewport1;
-extern GtkWidget *dialog_send_viewport2;
-extern GtkWidget *dialog_send_hbox;
+char fullscreen_flag;
 
 extern GtkWidget *dialog_IDinput;
 char server_name[16];
 
 GtkWidget *dialog_lock;
 GtkWidget *dialog_lock_table;
-extern GtkWidget *dialog_lock_viewport;
 
-GtkWidget *dialog_sendstop;
+#if 0
+GtkWidget *dialog_record;
+GtkWidget *dialog_record_table;
+int recording (int rec_time, int fps, char *geometry);
+#endif
 
 GtkWidget *dialog_quit;
 
 GtkWidget *dialog_version;
 
+GtkWidget *dialog_notice;
+
+extern void *AcceptLoop (void *arg);
+extern int SendRecvLoop (int acc, int fsize, char *fname);
+
+
 /*******************************************************************
  *ᥤ󥦥ɥФ륤٥ȤΥХåؿ
  *******************************************************************/
@@ -150,10 +157,8 @@ on_main_drawingarea_configure_event        (GtkWidget       *widget,
   clientNum = draw_info[page].client_num[da_num];
   if (clientNum != EMPTY) {
     CreateImageInfo(FALSE);
-    //printf("change_rfbsock1 from:%d ",rfbsock);
-    //rfbsock = server_CB.client_grp[clientNum]->vncdsp;
-    //printf("to:%d\n",rfbsock);
-    SendAllFramebufferUpdateRequestSpecified(server_CB.client_grp[clientNum]->vncdsp);
+    draw_image(gdkpixmap[page][da_num], gdkGC, gdkimage[clientNum], 0, 0, 0, 0,
+               gdkimage[clientNum]->width, gdkimage[clientNum]->height);
   }
 
   return TRUE;
@@ -207,6 +212,7 @@ on_main_drawingarea_button_press_event     (GtkWidget       *widget,
     if (event->type == GDK_2BUTTON_PRESS) {
       SETCTRL(clientNum, FALSE);
       expanding_screen();
+      GtkWidget *window_ex_togglebutton = lookup_widget(GTK_WIDGET(window_ex), "window_ex_togglebutton");
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(window_ex_togglebutton), FALSE);
     }
   }
@@ -274,6 +280,7 @@ on_viewset_activate                    (GtkMenuItem     *menuitem,
       dialog_viewset_clientnum[pCnt][dCnt] = EMPTY;
 
   dialog_viewset = create_dialog_viewset();
+  GtkWidget *dialog_viewset_viewport = lookup_widget(GTK_WIDGET(dialog_viewset), "dialog_viewset_viewport");
   dialog_viewset_table = gtk_table_new (2*tab_num-1, tab_num, FALSE);
   gtk_widget_show (dialog_viewset_table);
   gtk_container_add (GTK_CONTAINER (dialog_viewset_viewport), dialog_viewset_table);
@@ -299,6 +306,7 @@ on_send_activate                       (GtkMenuItem     *menuitem,
     send_state_tmp[Cnt] = GETSEND(Cnt);
     if (server_CB.user_num == ++user_cnt) break;
   }
+  fullscreen_flag = 0;	// ǥեȲ̾復ɥ
 
   dialog_send = create_dialog_send();
 
@@ -322,6 +330,9 @@ on_send_activate                       (GtkMenuItem     *menuitem,
 		      G_CALLBACK (on_dialog_send_checkbutton1_toggled),
 		      (gpointer) pCnt);
   }
+
+  GtkWidget *dialog_send_viewport1 = lookup_widget(GTK_WIDGET(dialog_send), "dialog_send_viewport1");
+  GtkWidget *dialog_send_viewport2 = lookup_widget(GTK_WIDGET(dialog_send), "dialog_send_viewport2");
   gtk_container_add (GTK_CONTAINER (dialog_send_viewport1), dialog_send_table1);
   gtk_widget_show (dialog_send_table1);
 
@@ -360,6 +371,7 @@ on_lock_activate                       (GtkMenuItem     *menuitem,
 		      G_CALLBACK (on_dialog_lock_checkbutton1_toggled),
 		      (gpointer) pCnt);
   }
+  GtkWidget *dialog_lock_viewport = lookup_widget(GTK_WIDGET(dialog_lock), "dialog_lock_viewport");
   gtk_container_add (GTK_CONTAINER (dialog_lock_viewport), dialog_lock_table);
   gtk_widget_show (dialog_lock_table);
 
@@ -368,14 +380,6 @@ on_lock_activate                       (GtkMenuItem     *menuitem,
 }
 
 
-void
-on_usage_activate                      (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
-{
-
-}
-
-
 void
 on_version_activate                    (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -459,8 +463,8 @@ void makeTable_dialog_viewset(int pCnt)
 		      (GtkAttachOptions) (GTK_FILL), 0, 0);
   }
 
-  /* labeltab xפκ */
-  sprintf(labelname, "\343\202\277\343\203\226%d", pCnt+1);
+  /* label "tab x" */
+  sprintf(labelname, _("tab %d"), pCnt+1);
   labelTab[pCnt] = gtk_label_new (_(labelname));
   gtk_widget_show (labelTab[pCnt]);
   gtk_table_attach (GTK_TABLE (dialog_viewset_table), labelTab[pCnt], 0, 1, 2*pCnt, 2*pCnt+1,
@@ -485,8 +489,8 @@ void makeTable_dialog_viewset(int pCnt)
   gtk_widget_show (hbox_row[pCnt]);
   gtk_box_pack_start (GTK_BOX (vbox[pCnt]), hbox_row[pCnt], TRUE, TRUE, 0);
 
-  /* labelֽġפκ */
-  label_row[pCnt] = gtk_label_new (_("\347\270\246"));
+  /* label "row" */
+  label_row[pCnt] = gtk_label_new (_("row"));
   gtk_widget_show (label_row[pCnt]);
   gtk_box_pack_start (GTK_BOX (hbox_row[pCnt]), label_row[pCnt], FALSE, FALSE, 0);
 
@@ -500,8 +504,8 @@ void makeTable_dialog_viewset(int pCnt)
   gtk_widget_show (hbox_col[pCnt]);
   gtk_box_pack_start (GTK_BOX (vbox[pCnt]), hbox_col[pCnt], TRUE, TRUE, 0);
 
-  /* labelֲפκ */
-  label_col[pCnt] = gtk_label_new (_("\346\250\252"));
+  /* label "column" */
+  label_col[pCnt] = gtk_label_new (_("column"));
   gtk_widget_show (label_col[pCnt]);
   gtk_box_pack_start (GTK_BOX (hbox_col[pCnt]), label_col[pCnt], FALSE, FALSE, 0);
 
@@ -665,11 +669,13 @@ on_dialog_viewset_button_moveupg_clicked      (GtkButton       *button,
     dialog_viewset_clientnum[dialog_viewset_page][dCnt] = dialog_viewset_clientnum[dialog_viewset_page][dCnt + 1];
     dCnt++;
   }
-
   gtk_container_remove(GTK_CONTAINER(dialog_viewset_listviewport[dialog_viewset_page]), dialog_viewset_list[dialog_viewset_page]);
   makeList_dialog_viewset(dialog_viewset_page);
-  gtk_container_remove(GTK_CONTAINER(dialog_viewset_listviewport[dialog_viewset_page - 1]), dialog_viewset_list[dialog_viewset_page - 1]);
-  makeList_dialog_viewset(dialog_viewset_page - 1);
+
+  dialog_viewset_page--;
+  dialog_viewset_area = bottom;
+  gtk_container_remove(GTK_CONTAINER(dialog_viewset_listviewport[dialog_viewset_page]), dialog_viewset_list[dialog_viewset_page]);
+  makeList_dialog_viewset(dialog_viewset_page);
 }
 
 
@@ -686,6 +692,7 @@ on_dialog_viewset_button_moveup_clicked       (GtkButton       *button,
   tmp = dialog_viewset_clientnum[dialog_viewset_page][dialog_viewset_area];
   dialog_viewset_clientnum[dialog_viewset_page][dialog_viewset_area] = dialog_viewset_clientnum[dialog_viewset_page][dialog_viewset_area - 1];
   dialog_viewset_clientnum[dialog_viewset_page][dialog_viewset_area - 1] = tmp;
+  dialog_viewset_area--;
 
   gtk_container_remove(GTK_CONTAINER(dialog_viewset_listviewport[dialog_viewset_page]), dialog_viewset_list[dialog_viewset_page]);
   makeList_dialog_viewset(dialog_viewset_page);
@@ -705,6 +712,7 @@ on_dialog_viewset_button_movedown_clicked     (GtkButton       *button,
   tmp = dialog_viewset_clientnum[dialog_viewset_page][dialog_viewset_area];
   dialog_viewset_clientnum[dialog_viewset_page][dialog_viewset_area] = dialog_viewset_clientnum[dialog_viewset_page][dialog_viewset_area + 1];
   dialog_viewset_clientnum[dialog_viewset_page][dialog_viewset_area + 1] = tmp;
+  dialog_viewset_area++;
 
   gtk_container_remove(GTK_CONTAINER(dialog_viewset_listviewport[dialog_viewset_page]), dialog_viewset_list[dialog_viewset_page]);
   makeList_dialog_viewset(dialog_viewset_page);
@@ -729,11 +737,13 @@ on_dialog_viewset_button_movedowng_clicked    (GtkButton       *button,
     dialog_viewset_clientnum[dialog_viewset_page][dCnt] = dialog_viewset_clientnum[dialog_viewset_page][dCnt + 1];
     dCnt++;
   }
-
   gtk_container_remove(GTK_CONTAINER(dialog_viewset_listviewport[dialog_viewset_page]), dialog_viewset_list[dialog_viewset_page]);
   makeList_dialog_viewset(dialog_viewset_page);
-  gtk_container_remove(GTK_CONTAINER(dialog_viewset_listviewport[dialog_viewset_page + 1]), dialog_viewset_list[dialog_viewset_page + 1]);
-  makeList_dialog_viewset(dialog_viewset_page + 1);
+
+  dialog_viewset_page++;
+  dialog_viewset_area = bottom;
+  gtk_container_remove(GTK_CONTAINER(dialog_viewset_listviewport[dialog_viewset_page]), dialog_viewset_list[dialog_viewset_page]);
+  makeList_dialog_viewset(dialog_viewset_page);
 }
 
 
@@ -758,7 +768,8 @@ add_to_dialog_viewset(int cnum)
 
   if (dialog_viewset == NULL) return;
   for (pCnt = 0; pCnt < tab_num_tmp; pCnt++) {
-    for (dCnt = 0; dCnt < TABGROUP_MAX; dCnt++){
+    for (dCnt = 0; dCnt < TABGROUP_MAX; dCnt++) {
+      if (dialog_viewset_clientnum[pCnt][dCnt] == cnum) return;
       if (dialog_viewset_clientnum[pCnt][dCnt] == EMPTY) {
 	dialog_viewset_clientnum[pCnt][dCnt] = cnum;
 	item = gtk_list_item_new_with_label(server_CB.client_grp[cnum]->client_ID);
@@ -785,110 +796,52 @@ void
 expanding_screen()
 {
   if (window_ex == NULL) {
-    window_ex = create_expandedwindow();
+    SETVIEW(clientNum, TRUE);
+    clientNum_ex = clientNum;
+    window_ex = create_window_ex();
+    GtkWidget *label_ex = lookup_widget(GTK_WIDGET(window_ex), "label_ex");
+    GtkWidget *aspectframe = lookup_widget(GTK_WIDGET(window_ex), "aspectframe");
+    drawingarea_ex = lookup_widget(GTK_WIDGET(window_ex), "drawingarea_ex");
+
+    gtk_label_set_text (GTK_LABEL(label_ex), server_CB.client_grp[clientNum]->client_ID);
+    gtk_widget_show(label_ex);
+
+    float aspect = (float)server_CB.client_grp[clientNum_ex]->serverInitMsg.framebufferWidth / (float)server_CB.client_grp[clientNum_ex]->serverInitMsg.framebufferHeight;
+    gtk_aspect_frame_set(GTK_ASPECT_FRAME(aspectframe), 0.5, 0.5, aspect, FALSE);
+    gtk_widget_set_size_request (aspectframe, exwindowWidth, exwindowHeight);
+    gtk_widget_show(aspectframe);
+
+    gtk_widget_set_events (drawingarea_ex, GDK_EXPOSURE_MASK | GDK_POINTER_MOTION_MASK
+			| GDK_POINTER_MOTION_HINT_MASK | GDK_BUTTON_MOTION_MASK | GDK_BUTTON_PRESS_MASK
+			| GDK_BUTTON_RELEASE_MASK | GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK
+			| GDK_FOCUS_CHANGE_MASK | GDK_STRUCTURE_MASK);
+
+    smallimage_ex = gdk_image_new (GDK_IMAGE_FASTEST, gdkvis,
+                         server_CB.client_grp[clientNum]->serverInitMsg.framebufferWidth,
+                         server_CB.client_grp[clientNum]->serverInitMsg.framebufferHeight);
+
     gtk_widget_show(window_ex);
   } else if (clientNum_ex != clientNum) {
     SETVIEW(clientNum_ex, FALSE);
     SETCTRL(clientNum_ex, FALSE);
+    GtkWidget *label_ex = lookup_widget(GTK_WIDGET(window_ex), "label_ex");
+    GtkWidget *window_ex_togglebutton = lookup_widget(GTK_WIDGET(window_ex), "window_ex_togglebutton");
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(window_ex_togglebutton), FALSE);
     clientNum_ex = clientNum;
+    CreateImageInfo(TRUE);
     SETVIEW(clientNum_ex, TRUE);
     gdk_image_destroy(smallimage_ex);
     smallimage_ex = gdk_image_new (GDK_IMAGE_FASTEST, gdkvis,
 				   server_CB.client_grp[clientNum_ex]->serverInitMsg.framebufferWidth,
 				   server_CB.client_grp[clientNum_ex]->serverInitMsg.framebufferHeight);
     gtk_label_set_text(GTK_LABEL(label_ex), server_CB.client_grp[clientNum_ex]->client_ID);
-    //rfbsock = server_CB.client_grp[clientNum_ex]->vncdsp;
     clientNum = clientNum_ex;
-    SendAllFramebufferUpdateRequestSpecified(server_CB.client_grp[clientNum_ex]->vncdsp);
+    draw_image(pixmap_ex, gdkGC, gdkimage[clientNum_ex], 0, 0, 0, 0,
+               gdkimage[clientNum_ex]->width, gdkimage[clientNum_ex]->height);
   }
 }
 
 
-/*
-  ɽѥɥκ
- */
-GtkWidget *create_expandedwindow(void)
-{
-  GtkWidget *window;
-  GtkWidget *vbox;
-  GtkWidget *hbox;
-
-  SETVIEW(clientNum, TRUE);
-  clientNum_ex = clientNum;
-
-  /* ɥκ */
-  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_default_size (GTK_WINDOW(window), exwindowWidth, exwindowHeight);
-  gtk_window_set_title (GTK_WINDOW (window), _("\347\224\273\351\235\242\346\213\241\345\244\247"));
-
-  vbox = gtk_vbox_new (FALSE, 0);
-  gtk_widget_show (vbox);
-  gtk_container_add (GTK_CONTAINER (window), vbox);
-
-  hbox = gtk_hbox_new (FALSE, 0);
-  gtk_widget_show (hbox);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-
-  /* 饤ȤIDɽlabelκ */
-  label_ex = gtk_label_new (_(server_CB.client_grp[clientNum]->client_ID));
-  gtk_widget_show (label_ex);
-  gtk_box_pack_start (GTK_BOX (hbox), label_ex, TRUE, TRUE, 0);
-
-  /* toggle buttonκ */
-  window_ex_togglebutton = gtk_toggle_button_new_with_mnemonic (_("\346\223\215\344\275\234ON/OFF"));
-  gtk_widget_show (window_ex_togglebutton);
-  gtk_box_pack_start (GTK_BOX (hbox), window_ex_togglebutton, FALSE, FALSE, 0);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(window_ex_togglebutton), FALSE);
-
-  /* drawing areaκ */
-  drawingarea_ex = gtk_drawing_area_new ();
-  gtk_widget_show (drawingarea_ex);
-  gtk_box_pack_start (GTK_BOX (vbox), drawingarea_ex, TRUE, TRUE, 0);
-  gtk_widget_set_events (drawingarea_ex, GDK_EXPOSURE_MASK | GDK_POINTER_MOTION_MASK
-			 | GDK_POINTER_MOTION_HINT_MASK | GDK_BUTTON_MOTION_MASK | GDK_BUTTON_PRESS_MASK
-			 | GDK_BUTTON_RELEASE_MASK | GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK
-			 | GDK_FOCUS_CHANGE_MASK | GDK_STRUCTURE_MASK);
-
-  g_signal_connect ((gpointer) window, "delete_event",
-                    G_CALLBACK (on_window_ex_delete_event),
-                    NULL);
-  g_signal_connect ((gpointer) window, "key_press_event",
-                    G_CALLBACK (on_window_ex_key_press_event),
-                    NULL);
-  g_signal_connect ((gpointer) window, "key_release_event",
-                    G_CALLBACK (on_window_ex_key_release_event),
-                    NULL);
-  g_signal_connect ((gpointer) window, "focus_out_event",
-                    G_CALLBACK (on_window_ex_focus_out_event),
-                    NULL);
-  g_signal_connect ((gpointer) drawingarea_ex, "button_press_event",
-                    G_CALLBACK (on_drawingarea_ex_button_press_event),
-                    NULL);
-  g_signal_connect ((gpointer) drawingarea_ex, "button_release_event",
-                    G_CALLBACK (on_drawingarea_ex_button_release_event),
-                    NULL);
-  g_signal_connect ((gpointer) drawingarea_ex, "configure_event",
-                    G_CALLBACK (on_drawingarea_ex_configure_event),
-                    NULL);
-  g_signal_connect ((gpointer) drawingarea_ex, "expose_event",
-                    G_CALLBACK (on_drawingarea_ex_expose_event),
-                    NULL);
-  g_signal_connect ((gpointer) drawingarea_ex, "motion_notify_event",
-                    G_CALLBACK (on_drawingarea_ex_motion_notify_event),
-                    NULL);
-  g_signal_connect ((gpointer) window_ex_togglebutton, "toggled",
-		    G_CALLBACK (on_window_ex_togglebutton_toggled),
-		    NULL);
-
-  smallimage_ex = gdk_image_new (GDK_IMAGE_FASTEST, gdkvis,
-				 server_CB.client_grp[clientNum]->serverInitMsg.framebufferWidth,
-				 server_CB.client_grp[clientNum]->serverInitMsg.framebufferHeight);
-
-  return window;
-}
-
-
 gboolean
 on_window_ex_key_press_event             (GtkWidget       *widget,
                                         GdkEventKey     *event,
@@ -958,6 +911,26 @@ on_window_ex_focus_out_event             (GtkWidget       *widget,
   return TRUE;
 }
 
+gboolean
+on_aspectframe_configure_event         (GtkWidget       *widget,
+                                        GdkEventConfigure *event,
+                                        gpointer         user_data)
+{
+
+  return FALSE;
+}
+
+
+gboolean
+on_aspectframe_expose_event            (GtkWidget       *widget,
+                                        GdkEventExpose  *event,
+                                        gpointer         user_data)
+{
+
+  return FALSE;
+}
+
+
 
 void
 on_window_ex_togglebutton_toggled       (GtkToggleButton *togglebutton,
@@ -980,8 +953,11 @@ on_window_ex_delete_event                (GtkWidget       *widget,
   SETVIEW(clientNum_ex, FALSE);
   SETCTRL(clientNum_ex, FALSE);
   gdk_image_destroy(smallimage_ex);
+  smallimage_ex = NULL;
   gtk_widget_destroy(window_ex);
   window_ex = NULL;
+  free(iinfo_ex);
+  iinfo_ex = NULL;
 
   return TRUE;
 }
@@ -1053,9 +1029,9 @@ on_drawingarea_ex_configure_event      (GtkWidget       *widget,
 		     0, 0, widget->allocation.width, widget->allocation.height);
 
   CreateImageInfo(TRUE);
-  //rfbsock = server_CB.client_grp[clientNum_ex]->vncdsp;
   clientNum = clientNum_ex;
-  SendAllFramebufferUpdateRequestSpecified(server_CB.client_grp[clientNum_ex]->vncdsp);
+  draw_image(pixmap_ex, gdkGC, gdkimage[clientNum], 0, 0, 0, 0,
+             gdkimage[clientNum]->width, gdkimage[clientNum]->height);
 
   return TRUE;
 }
@@ -1119,33 +1095,38 @@ create_rightclickmenu1 (gpointer user_data)
   GtkWidget *screen_lock;
   GtkWidget *screen_send;
   GtkWidget *screen_send_stop;
+//  GtkWidget *screen_record;
 
   rightclickmenu1 = gtk_menu_new ();
 
-  viewset = gtk_menu_item_new_with_mnemonic (_("\350\241\250\347\244\272\350\250\255\345\256\232"));
+  viewset = gtk_menu_item_new_with_mnemonic (_("Preferences of View"));
   gtk_widget_show (viewset);
   gtk_container_add (GTK_CONTAINER (rightclickmenu1), viewset);
 
-  screen_expand = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\346\213\241\345\244\247"));
+  screen_expand = gtk_menu_item_new_with_mnemonic (_("Expand"));
   gtk_widget_show (screen_expand);
   gtk_container_add (GTK_CONTAINER (rightclickmenu1), screen_expand);
 
-  screen_ctrl = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\346\223\215\344\275\234"));
+  screen_ctrl = gtk_menu_item_new_with_mnemonic (_("Operate"));
   gtk_widget_show (screen_ctrl);
   gtk_container_add (GTK_CONTAINER (rightclickmenu1), screen_ctrl);
 
-  screen_lock = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\343\203\255\343\203\203\343\202\257/\350\247\243\351\231\244"));
+  screen_lock = gtk_menu_item_new_with_mnemonic (_("Lock/Unlock"));
   gtk_widget_show (screen_lock);
   gtk_container_add (GTK_CONTAINER (rightclickmenu1), screen_lock);
 
-  screen_send = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\351\200\201\344\277\241"));
+  screen_send = gtk_menu_item_new_with_mnemonic (_("Send screen"));
   gtk_widget_show (screen_send);
   gtk_container_add (GTK_CONTAINER (rightclickmenu1), screen_send);
 
-  screen_send_stop = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\351\200\201\344\277\241\345\201\234\346\255\242"));
+  screen_send_stop = gtk_menu_item_new_with_mnemonic (_("Stop sending"));
   gtk_widget_show (screen_send_stop);
   gtk_container_add (GTK_CONTAINER (rightclickmenu1), screen_send_stop);
 
+//  screen_record = gtk_menu_item_new_with_mnemonic (_("Record screen"));
+//  gtk_widget_show (screen_record);
+//  gtk_container_add (GTK_CONTAINER (rightclickmenu1), screen_record);
+
   g_signal_connect ((gpointer) viewset, "activate",
                     G_CALLBACK (on_viewset_activate),
                     NULL);
@@ -1164,6 +1145,9 @@ create_rightclickmenu1 (gpointer user_data)
   g_signal_connect ((gpointer) screen_send_stop, "activate",
                     G_CALLBACK (on_screen_send_stop_activate),
                     (gpointer)c_num);
+//  g_signal_connect ((gpointer) screen_record, "activate",
+//                    G_CALLBACK (on_screen_record_activate),
+//                    (gpointer)c_num);
 
   return rightclickmenu1;
 }
@@ -1183,19 +1167,19 @@ create_rightclickmenu2 (gpointer user_data)
 
   rightclickmenu2 = gtk_menu_new ();
 
-  menuitem3 = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\346\223\215\344\275\234"));
+  menuitem3 = gtk_menu_item_new_with_mnemonic (_("Operate"));
   gtk_widget_show (menuitem3);
   gtk_container_add (GTK_CONTAINER (rightclickmenu2), menuitem3);
 
-  menuitem4 = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\343\203\255\343\203\203\343\202\257/\350\247\243\351\231\244"));
+  menuitem4 = gtk_menu_item_new_with_mnemonic (_("Lock/Unlock"));
   gtk_widget_show (menuitem4);
   gtk_container_add (GTK_CONTAINER (rightclickmenu2), menuitem4);
 
-  menuitem5 = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\351\200\201\344\277\241"));
+  menuitem5 = gtk_menu_item_new_with_mnemonic (_("Send screen"));
   gtk_widget_show (menuitem5);
   gtk_container_add (GTK_CONTAINER (rightclickmenu2), menuitem5);
 
-  menuitem6 = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\351\200\201\344\277\241\345\201\234\346\255\242"));
+  menuitem6 = gtk_menu_item_new_with_mnemonic (_("Stop sending screen"));
   gtk_widget_show (menuitem6);
   gtk_container_add (GTK_CONTAINER (rightclickmenu2), menuitem6);
 
@@ -1223,6 +1207,7 @@ on_screen_expand_activate              (GtkMenuItem     *menuitem,
   clientNum = (int)user_data;
   SETCTRL(clientNum, FALSE);
   expanding_screen();
+  GtkWidget *window_ex_togglebutton = lookup_widget(GTK_WIDGET(window_ex), "window_ex_togglebutton");
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(window_ex_togglebutton), FALSE);
 }
 
@@ -1233,14 +1218,15 @@ on_screen_ctrl_activate                (GtkMenuItem     *menuitem,
 {
   clientNum = (int)user_data;
   expanding_screen();
-  if (!GETCTRL(clientNum_ex)) {
-    SETCTRL(clientNum_ex, TRUE);
+  GtkWidget *window_ex_togglebutton = lookup_widget(GTK_WIDGET(window_ex), "window_ex_togglebutton");
+  if (!GETCTRL(clientNum)) {
+    SETCTRL(clientNum, TRUE);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(window_ex_togglebutton), TRUE);
   } else {
-    SETCTRL(clientNum_ex, FALSE);
+    SETCTRL(clientNum, FALSE);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(window_ex_togglebutton), FALSE);
   }
-  printf("clientNum_ex=%d\n", clientNum);
+  //printf("clientNum=%d\n", clientNum);
 }
 
 
@@ -1282,16 +1268,159 @@ void
 on_screen_send_stop_activate           (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  int c_num = (int)user_data;
+  on_send_activate(menuitem, NULL);
 
-  if (GETRECV(c_num)) {
-    dialog_sendstop = create_dialog_sendstop(c_num);
-    gtk_widget_show(dialog_sendstop);
-    gtk_grab_add(dialog_sendstop);
-  }
+  // open 2 page
+  GtkWidget *notebook = lookup_widget(dialog_send, "notebook");
+  gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 1);
 }
 
 
+#if 0
+/*******************************************************************
+ *ϿǻѤؿ
+ *******************************************************************/
+void
+on_screen_record_activate              (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+  int pCnt, dCnt, flag = 0;
+  dialog_record = create_dialog_record();
+  dialog_record_table = makeTable_userList();
+  GtkWidget *checkbutton0 = lookup_widget(dialog_record, "dialog_record_checkbutton0");
+
+  // can't setting resolution (widget hide)
+  GtkWidget *hbox5 = lookup_widget(dialog_record, "hbox5");
+  gtk_widget_hide(hbox5);
+
+  for (pCnt = 0; pCnt < tab_num; pCnt++) {
+    for (dCnt = 0; dCnt < TABGROUP_MAX; dCnt++) {
+      if (draw_info[pCnt].client_num[dCnt] == EMPTY) continue;
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog_send_checkbutton2[pCnt][dCnt]), \
+		      GETREC(draw_info[pCnt].client_num[dCnt])); g_signal_connect ((gpointer) dialog_send_checkbutton2[pCnt][dCnt], "toggled",
+		      G_CALLBACK (on_dialog_lock_checkbutton2_toggled), 
+		      (gpointer) ((pCnt << 8)+dCnt));
+      flag += gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON ( dialog_send_checkbutton2[pCnt][dCnt]));
+    }
+    g_signal_connect ((gpointer) dialog_send_checkbutton1[pCnt], "toggled", 
+		    G_CALLBACK (on_dialog_lock_checkbutton1_toggled),
+		    (gpointer) pCnt);
+    g_signal_connect ((gpointer) checkbutton0, "toggled", 
+		    G_CALLBACK (on_dialog_lock_checkbutton0_toggled),
+		    (gpointer) pCnt);
+  }
+
+  // start or stop record button hide
+  if (flag) {
+    GtkWidget *button_record_start = lookup_widget(dialog_record, "button_record_start");
+    gtk_widget_hide(button_record_start);
+  }
+  else {
+    GtkWidget *button_record_stop = lookup_widget(dialog_record, "button_record_stop");
+    gtk_widget_hide(button_record_stop);
+  }
+  GtkWidget *dialog_record_viewport = lookup_widget(GTK_WIDGET(dialog_record), "dialog_record_viewport");
+  gtk_container_add (GTK_CONTAINER (dialog_record_viewport), dialog_record_table);
+  gtk_widget_show(dialog_record_table);
+  gtk_widget_show(dialog_record);
+  gtk_grab_add(dialog_record);
+}
+
+
+void
+on_dialog_rec_start_button_clicked     (GtkButton       *button,
+                                        gpointer         user_data)
+{
+  // start <-> stop change
+  GtkWidget *button_record_start = lookup_widget(dialog_record, "button_record_start");
+  GtkWidget *button_record_stop = lookup_widget(dialog_record, "button_record_stop");
+  gtk_widget_hide(button_record_start);
+  gtk_widget_show(button_record_stop);
+
+  // get recording time, FPS, and resolution
+  GtkWidget *sppinbutton_record = lookup_widget(GTK_WIDGET(dialog_record), "spinbutton_rec_time");
+  GtkWidget *spinbutton_fps = lookup_widget(GTK_WIDGET(dialog_record), "spinbutton_fps");
+  GtkWidget *combo_entry = lookup_widget(GTK_WIDGET(dialog_record), "combo_entry1");
+
+  int rec_time = gtk_spin_button_get_value(GTK_SPIN_BUTTON(sppinbutton_record));
+  int fps = gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinbutton_fps));
+  gchar geometry[IDLENGTH];
+  strcpy(geometry, gtk_entry_get_text (GTK_ENTRY(combo_entry))); 
+
+  printf("recording time:%d, fps:%d, geometry(resolution):%s\n", rec_time, fps, geometry);
+
+  recording(rec_time, fps, geometry);
+}
+
+
+void
+on_dialog_rec_stop_button_clicked      (GtkButton       *button,
+                                        gpointer         user_data)
+{
+  // start <-> stop change
+  GtkWidget *button_record_start = lookup_widget(dialog_record, "button_record_start");
+  GtkWidget *button_record_stop = lookup_widget(dialog_record, "button_record_stop");
+  gtk_widget_show(button_record_start);
+  gtk_widget_hide(button_record_stop);
+
+  // all chech button clear
+  GtkWidget *checkbutton0 = lookup_widget(dialog_record, "dialog_record_checkbutton0");
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton0), TRUE);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton0), FALSE);
+
+  recording(-1, -1, "");
+}
+
+
+void
+on_dialog_rec_close_button_clicked     (GtkButton       *button,
+                                        gpointer         user_data)
+{
+  gtk_grab_remove(dialog_record);
+  gtk_widget_destroy(dialog_record);
+}
+
+
+gboolean
+on_dialog_record_delete_event          (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data)
+{
+  gtk_grab_remove(dialog_record);
+  gtk_widget_destroy(dialog_record);
+  return TRUE;
+}
+
+
+int
+recording (int rec_time, int fps, char *geometry)
+{
+  int p, d, num, rec_flag;
+
+  for (p = 0; p < tab_num; p++) {
+    for (d = 0; d < TABGROUP_MAX; d++) {
+      if ((num= draw_info[p].client_num[d]) == EMPTY) continue;
+
+      rec_flag = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(dialog_send_checkbutton2[p][d]));
+
+      printf("#####[rec control:client:%d(%s) flag %d]#####\n", num, inet_ntoa(server_CB.client_grp[num]->client_ip), rec_flag);
+      if (rec_time > 0 && (GETREC(num) || rec_flag)) {
+        // record start
+        SendRecMsg(START, server_CB.client_grp[num]->ctldsp, rec_time, fps, geometry);
+        SETREC(num, START);
+      } else if (rec_time < 0) {
+        // record stop
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog_send_checkbutton2[p][d]), FALSE);
+        SendRecMsg(STOP, server_CB.client_grp[num]->ctldsp, 0, 0, NULL);
+	SETREC(num, STOP);
+      }
+    }
+  }
+  return 0;
+}
+
+#endif
+
 /*******************************************************************
  *ǻѤؿ
  *******************************************************************/
@@ -1302,6 +1431,7 @@ on_screen_send_stop_activate           (GtkMenuItem     *menuitem,
 void makeCombobox1_dialog_send(void)
 {
   int pCnt;
+  GtkWidget *dialog_send_hbox = lookup_widget(GTK_WIDGET(dialog_send), "dialog_send_hbox");
 
   dialog_send_comboboxentry1 = gtk_combo_box_entry_new_text ();
   gtk_widget_show (dialog_send_comboboxentry1);
@@ -1312,7 +1442,7 @@ void makeCombobox1_dialog_send(void)
   for (pCnt = 0; pCnt < tab_num; pCnt++)
     gtk_combo_box_append_text (GTK_COMBO_BOX (dialog_send_comboboxentry1), _(draw_info[pCnt].group_name));
 
-  dialog_send_label_ID = gtk_label_new (_("\343\203\246\343\203\274\343\202\266 ID"));
+  dialog_send_label_ID = gtk_label_new (_("User ID"));
   gtk_widget_show (dialog_send_label_ID);
   gtk_box_pack_start (GTK_BOX (dialog_send_hbox), dialog_send_label_ID, FALSE, FALSE, 0);
 }
@@ -1323,6 +1453,7 @@ void makeCombobox1_dialog_send(void)
  */
 void makeCombobox2_dialog_send(void)
 {
+  GtkWidget *dialog_send_hbox = lookup_widget(GTK_WIDGET(dialog_send), "dialog_send_hbox");
   dialog_send_comboboxentry2 = gtk_combo_box_entry_new_text ();
   gtk_widget_show (dialog_send_comboboxentry2);
   gtk_box_pack_start (GTK_BOX (dialog_send_hbox), dialog_send_comboboxentry2, TRUE, TRUE, 0);
@@ -1358,8 +1489,8 @@ GtkWidget *makeTable_userList(void)
 		        (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
     }
 
-    /* label֥ xפκ */
-    sprintf(tab, "\343\202\277\343\203\226%d", pCnt+1);
+    /* label "tab x" */
+    sprintf(tab, _("tab %d"), pCnt+1);
     label = gtk_label_new (_(tab));
     gtk_widget_show (label);
     gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2*pCnt, 2*pCnt+1,
@@ -1578,6 +1709,7 @@ on_dialog_send_comboboxentry1_changed      (GtkComboBox     *combobox,
 {
   int p, i, num;
   char *string;
+  GtkWidget *dialog_send_hbox = lookup_widget(GTK_WIDGET(dialog_send), "dialog_send_hbox");
 
   if (src_checkbutton != NULL)
     gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (src_checkbutton), FALSE);
@@ -1750,7 +1882,7 @@ send_start(void)
 	calcRateCallback ((gpointer)c_num);
 	SendAllowMsg(c_num, server_CB.client_grp[c_num]->client_ID);
       } else {
-	(*shm_asym[c_num]).flag = 2;
+	(*shm_asym[c_num]).flag = CAST_STOP;
 	int shmctlck;
 	int res = shmdt(shm_asym[c_num]);
 	shmctlck = shmctl(server_CB.client_grp[c_num]->shm_id, IPC_RMID, 0);
@@ -1760,7 +1892,8 @@ send_start(void)
 	shm_asym[c_num] = NULL;
 
 	gtk_timeout_remove (server_CB.client_grp[c_num]->calcrate_tag);
-	gtk_timeout_remove (server_CB.client_grp[c_num]->resend_tag);
+	if (Resend_flag)
+	  gtk_timeout_remove (server_CB.client_grp[c_num]->resend_tag);
         close (server_CB.cstdsp[server_CB.client_grp[c_num]->cast_grp]);
       }
     }
@@ -1774,7 +1907,7 @@ send_start(void)
     if (server_CB.client_grp[c_num] == NULL) continue;
     if ((!recv_state_tmp[c_num] && GETRECV(c_num)) || (recv_state_tmp[c_num] && !GETRECV(c_num))) {
       SETRECV(c_num, recv_state_tmp[c_num]);
-      SendCastMsg(GETRECV(c_num), c_num);
+      SendCastMsg(GETRECV(c_num), c_num, fullscreen_flag);
     }
     if (server_CB.user_num == ++user_cnt) break;
   }
@@ -1811,6 +1944,9 @@ on_dialog_send_buttonApply_clicked         (GtkButton       *button,
 {
   int Cnt, pCnt, dCnt;
   int user_cnt = 0;
+  GtkWidget *dialog_send_hbox = lookup_widget(GTK_WIDGET(dialog_send), "dialog_send_hbox");
+  GtkWidget *dialog_send_viewport1 = lookup_widget(GTK_WIDGET(dialog_send), "dialog_send_viewport1");
+  GtkWidget *dialog_send_viewport2 = lookup_widget(GTK_WIDGET(dialog_send), "dialog_send_viewport2");
 
   send_start();
 
@@ -1975,107 +2111,9 @@ void locking_start(void)
 
 
 /*******************************************************************
- *å˥塼ߤǻѤؿ
+ *MultiVNCλǧǻѤؿ
  *******************************************************************/
 
-gboolean
-on_dialog_sendstop_delete_event                (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data)
-{
-  gtk_grab_remove(dialog_sendstop);
-  gtk_widget_destroy(dialog_sendstop);
-
-  return TRUE;
-}
-
-
-void
-on_dialog_sendstop_buttonOK_clicked            (GtkButton       *button,
-                                        gpointer         user_data)
-{
-  int c_num = (int)user_data;
-
-  SETRECV(c_num, FALSE);
-  SendCastMsg(FALSE, c_num);
-
-  gtk_grab_remove(dialog_sendstop);
-  gtk_widget_destroy(dialog_sendstop);
-}
-
-
-void
-on_dialog_sendstop_buttonCancel_clicked        (GtkButton       *button,
-                                        gpointer         user_data)
-{
-  gtk_grab_remove(dialog_sendstop);
-  gtk_widget_destroy(dialog_sendstop);
-}
-
-
-/*
-  ߤΥåɽκ
- */
-GtkWidget*
-create_dialog_sendstop (int c_num)
-{
-  int src;
-  char message[256];
-  GtkWidget *dialog_sendstop;
-  GtkWidget *dialog_sendstop_vbox;
-  GtkWidget *label_stop;
-  GtkWidget *dialog_action_area;
-  GtkWidget *buttonOK;
-  GtkWidget *buttonCancel;
-
-  /* κ */
-  dialog_sendstop = gtk_dialog_new ();
-  gtk_window_set_title (GTK_WINDOW (dialog_sendstop), _("MultiVNC \351\200\201\344\277\241\345\201\234\346\255\242\347\242\272\350\252\215"));
-  gtk_window_set_type_hint (GTK_WINDOW (dialog_sendstop), GDK_WINDOW_TYPE_HINT_DIALOG);
-
-  dialog_sendstop_vbox = GTK_DIALOG (dialog_sendstop)->vbox;
-  gtk_widget_show (dialog_sendstop_vbox);
-
-  /* åɽlabelκ */
-  src = server_CB.cast_src[server_CB.client_grp[c_num]->recv_grp];
-  sprintf(message, "%s\343\201\213\343\202\211\n%s\343\201\270\343\201\256\351\200\201\344\277\241\343\202\222\345\201\234\346\255\242\343\201\227\343\201\276\343\201\231\343\201\213\357\274\237", server_CB.client_grp[src]->client_ID, server_CB.client_grp[c_num]->client_ID);
-  label_stop = gtk_label_new (_(message));
-  gtk_widget_show (label_stop);
-  gtk_box_pack_start (GTK_BOX (dialog_sendstop_vbox), label_stop, FALSE, FALSE, 0);
-
-  dialog_action_area = GTK_DIALOG (dialog_sendstop)->action_area;
-  gtk_widget_show (dialog_action_area);
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_END);
-
-  /* OKܥκ */
-  buttonOK = gtk_button_new_from_stock ("gtk-ok");
-  gtk_widget_show (buttonOK);
-  gtk_dialog_add_action_widget (GTK_DIALOG (dialog_sendstop), buttonOK, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS (buttonOK, GTK_CAN_DEFAULT);
-
-  /* Cancelܥκ */
-  buttonCancel = gtk_button_new_from_stock ("gtk-cancel");
-  gtk_widget_show (buttonCancel);
-  gtk_dialog_add_action_widget (GTK_DIALOG (dialog_sendstop), buttonCancel, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS (buttonCancel, GTK_CAN_DEFAULT);
-
-  g_signal_connect ((gpointer) dialog_sendstop, "delete_event",
-                    G_CALLBACK (on_dialog_sendstop_delete_event),
-                    NULL);
-
-  g_signal_connect ((gpointer) buttonOK, "clicked",
-                    G_CALLBACK (on_dialog_sendstop_buttonOK_clicked),
-                    (gpointer)c_num);
-
-  g_signal_connect ((gpointer) buttonCancel, "clicked",
-                    G_CALLBACK (on_dialog_sendstop_buttonCancel_clicked),
-                    NULL);
-
-  return dialog_sendstop;
-}
-
-
-
 gboolean
 on_dialog_quit_delete_event            (GtkWidget       *widget,
                                         GdkEvent        *event,
@@ -2109,6 +2147,10 @@ on_dialog_quit_buttonCancel_clicked    (GtkButton       *button,
 }
 
 
+/*******************************************************************
+ *СɽǻѤؿ
+ *******************************************************************/
+
 gboolean
 on_dialog_version_delete_event         (GtkWidget       *widget,
                                         GdkEvent        *event,
@@ -2127,3 +2169,46 @@ on_dialog_version_buttonOK_clicked     (GtkButton       *button,
   gtk_widget_destroy(dialog_version);
 }
 
+
+void
+on_dialog_send_fullscreen_radiobutton_toggled
+                                        (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+  fullscreen_flag = 1;
+}
+
+
+void
+on_dialog_send_window_radiobutton_toggled
+                                        (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+  fullscreen_flag = 0;
+}
+
+
+/*******************************************************************
+ *ΥǻѤؿ
+ *******************************************************************/
+
+gboolean
+on_dialog_notice_delete_event          (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data)
+{
+  gtk_widget_destroy(dialog_notice);
+//  gtk_main_quit();
+  return TRUE;
+}
+
+
+void
+on_dialog_notify_okbutton_clicked      (GtkButton       *button,
+                                        gpointer         user_data)
+{
+  gtk_widget_destroy(dialog_notice);
+//  gtk_main_quit();
+}
+
+
