@@ -480,3 +480,60 @@ on_dialog_record_checkbutton0_toggled  (GtkToggleButton *togglebutton,
 void
 on_dialog_lock_checkbutton0_toggled    (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
+
+void
+on_dialog_rec_button_clicked           (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_button_close_clicked     (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_stop_button_clicked          (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_close_button_clicked         (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_stop_button_clicked      (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_close_button_clicked     (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_start_button_clicked     (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_button_clicked           (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_spinbutton_fps_editing_done         (GtkCellEditable *celleditable,
+                                        gpointer         user_data);
+
+void
+on_combo_entry1_editing_done           (GtkCellEditable *celleditable,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_start_button_clicked     (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_stop_button_clicked      (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_close_button_clicked     (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_dialog_record_delete_event          (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
