@@ -1,16 +1,16 @@
-#include <stdio.h>
+#include "vncviewer.h"
 #include <sys/socket.h>
 #include <resolv.h>
 #include <arpa/inet.h>
-#include <errno.h>
 #include <netinet/in.h>
-#include "vncviewer.h"
+#include <errno.h>
 #include <mysql.h>
 
-#include <sys/shm.h>
 #include <unistd.h>
+#include <sys/shm.h>
 #include <sys/ipc.h>
 #include <sys/sem.h>
+#include <signal.h>
 
 typedef struct _GdkIOClosure GdkIOClosure;
 struct _GdkIOClosure
@@ -26,6 +26,7 @@ static void vncSocketCallback(gpointer clientData, gint fd, GdkInputCondition co
 static Bool CheckDrawingarea(int);
 static Bool DiscoverDrawingarea(int);
 void CheckLockClient(void);
+extern char *swf_file;
 
 int getClientFromCtldsp (int fd);
 int getClientFromVncdsp (int fd);
@@ -33,10 +34,14 @@ void SendCastMsg (char flag, int clientNum, char fullscreen);
 int ConnectMyself ();
 Bool AuthDB (char *client_ID);
 
+
 extern int multi_ttl;
 extern GtkWidget *main_window;
 GtkWidget *dialog_IDinput;
 
+//extern GtkWidget *dialog_record;
+
+
 /* shared memory */
 long *shm_sec;
 long *shm_usec;
@@ -510,11 +515,82 @@ controlSocketCallback (gpointer clientData, gint fd, GdkInputCondition condition
       server_CB.client_grp[clientNum]->r_time = tmptime.tv_usec;
 
       if (buf[1] & 0x01) SETRESEND (clientNum, 1);
+      if (!(buf[1] & RECSTATE)) SETREC (clientNum, 0);
       break;
 
+#if 0
+    case  rfbFileAdv:
+      {
+	size_t fsize, received = 0;
+	char fname[STRLENGTH +1];
+	char data[SWF_DATA +1];
+	FILE *fp;
+
+	if (read (socket, &fsize, sizeof(fsize)) <= 0) {
+	  fprintf(stderr, "client:%d fsize", clientNum);
+	  perror("read");
+	  return;
+	}
+	if ((received = recv (socket, fname, STRLENGTH, 0)) < STRLENGTH) {
+	  fprintf(stderr, "client:%dB file name", clientNum);
+	  perror("recv");
+	  return;
+	}
+	if ((received = recv (socket, data, SWF_DATA, 0)) < SWF_DATA) {
+	  fprintf(stderr, "client:%dB file data %dB get", clientNum, received);
+	  perror("recv");
+	  return;
+	}
+
+//	fprintf(stderr, "recv(cnum:%d flag:%d fsize:%d(%d) name:%s(%d) data:%d\n", clientNum, buf[1], fsize, sizeof(fsize), fname, sizeof(fname), sizeof(data));
+	switch (buf[1]) {
+	// START or CONTINUE
+	  case START:
+	      fprintf(stderr, "client:%d %s revcieve start.\n", clientNum, fname);
+	  case CONTINUE:
+	    if ((server_CB.client_grp[clientNum]->fp = fopen(fname, "a+")) == NULL) {
+	      fprintf(stderr, "client:%d ", clientNum);
+	      perror("fopen");
+	    }
+	    if(fwrite(data, fsize, 1, server_CB.client_grp[clientNum]->fp) <= 0) {
+//	    if(fwrite(data, received, 1, server_CB.client_grp[clientNum]->fp) <= 0) {
+	      fprintf(stderr, "client:%d ", clientNum);
+	      perror("fwrite");
+	    }
+	    fclose(server_CB.client_grp[clientNum]->fp);
+	    break;
+
+          case STOP:
+	    {
+	      fprintf(stderr, "client:%d %s(%d) revcieve done.\n", clientNum, fname, fsize);
+	      SETREC(clientNum, STOP);
+	      // bottun clear
+	      if (dialog_record != NULL)
+	        on_dialog_rec_stop_button_clicked(NULL, NULL);
+	      /*
+	      int pCnt = server_CB.client_grp[clientNum]->draw_page;
+	      int dCnt = server_CB.client_grp[clientNum]->draw_area;
+              gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog_send_checkbutton2[pCnt][dCnt]), GETREC(clientNum));
+	      */
+	      size_t size;
+	      size = get_file_size(fname);
+	      if (size != fsize) {
+	        fprintf(stderr, "%s transfer error.(%d/%d)\n", fname, size, fsize);
+	      }
+	      else {
+	        fprintf(stderr, "%s transfer success.(%d/%d)\n", fname, size, fsize);
+	      }
+	    }
+	    break;
+	}
+      }
+      break;
+
+#endif
+
     default:
       perror("Unknown Message Type");
-      printf(" %d\n",buf[0]);
+      printf("client:%d, type %d\n", clientNum, buf[0]);
       break;
   } 
   server_CB.client_grp[clientNum]->g_ctldsp = gdk_input_add_priority (server_CB.client_grp[clientNum]->ctldsp,
@@ -775,19 +851,6 @@ SendCastMsg (char flag, int clientNum, char fullscreen)
   len = write (server_CB.client_grp[clientNum]->ctldsp, &castadv, sizeof(CastAdv));
 }
 
-void 
-SendRecMsg (char flag, int clientNum, int rectime)
-{
-  RecAdv recadv;
-
-  bzero(&recadv, sizeof(RecAdv));
-  recadv.type = rfbRecAdv;
-  recadv.flag = flag;
-  recadv.rectime = rectime;
-
-  write (server_CB.client_grp[clientNum]->ctldsp, &recadv, sizeof(RecAdv));
-}
-
 void 
 SendLockMsg (char flag, int clientNum)
 {
@@ -893,3 +956,5 @@ sem_unlock ()
   semaphore = 1;
 #endif
 }
+
+
